network_tools library

Classes

ActiveHost
ActiveHost which implements comparable By default sort by hostId ascending
ARPData
HostScannerService
Scans for all hosts in a subnet.
MdnsInfo
MdnsScannerService
NetInterface
Represents a network interface with its network ID, host ID, and IP address.
OpenPort
Represents open port for a target Address
PortScannerService
Scans open port for a target Address or domain.
SendableActiveHost
Vendor
Gives vendor details matching as prefix of mac address

Properties

dbDirectory String
The directory path where the network tools database and assets are stored.
getter/setter pair
enableDebugging bool
Whether debugging is enabled for the network tools package.
getter/setter pair
tcpSrvRecordsList List<String>
List of common mDNS service records using the TCP protocol.
getter/setter pair
udpSrvRecordsList List<String>
List of common mDNS service records using the UDP protocol.
getter/setter pair

Functions

configureNetworkTools(String dbDirectory, {bool enableDebugging = false, bool rebuildData = false}) Future<void>
Configures the network tools package for Dart native platforms.
initializeNetworkTools(bool rebuildData) Future<void>
Initializes the ARP table and vendor table map for network operations.

Typedefs

ProgressCallback = void Function(double progress)
Progress Callback for scanners